summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-23 16:25:02 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-23 16:25:02 -0500
commitb54a51cf03490641c0cde1562be4221c760954fc (patch)
tree608b8d462e79056f8e8c1e49981d2365a50d4531
parent5105b278009c2c7c7c42023c2d04b4a526e1ce45 (diff)
downloadtde-style-lipstik-b54a51cf.tar.gz
tde-style-lipstik-b54a51cf.zip
Fix accidental FTBFS from last commit
-rw-r--r--style/lipstik.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/style/lipstik.cpp b/style/lipstik.cpp
index b6e203e..8fe630d 100644
--- a/style/lipstik.cpp
+++ b/style/lipstik.cpp
@@ -1,4 +1,4 @@
/* Lipstik widget style for KDE 3
Copyright (C) 2004-2007 Patrice Tremblay <poplixos@gmail.com>
http://www.poplix.info/lipstik
@@ -7,7 +7,7 @@
Copyright (C) 2003 Sandro Giessl <ceebx@users.sourceforge.net>
- based on the KDE style "dotNET":
+ based on the TDE style "dotNET":
Copyright (C) 2001-2002, Chris Lee <clee@kde.org>
Carsten Pfeiffer <pfeiffer@kde.org>
@@ -19,7 +19,7 @@
Copyright (c) 2002 Malte Starostik <malte@kde.org>
(c) 2002,2003 Maksim Orlovich <mo002j@mail.rochester.edu>
- based on the KDE3 HighColor Style
+ based on the TDE HighColor Style
Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
(C) 2001-2002 Fredrik H�glund <fredrik@kde.org>
Drawing routines adapted from the KDE2 HCStyle,
@@ -2895,9 +2895,9 @@ void LipstikStyle::drawControl(ControlElement element,
p->fillRect( TQRect(r.left(),r.top(), checkcol+4,r.bottom()-r.top()+1), getColor(cg, MenuStripeColor) );
} else {
if(_reverseGradients) {
- renderGradient(p, TQRect(r.left(),r.top(), checkcol+4,r.bottom()-r.top()+1), getColor(cg, MenuStripeColor), cg.ba$
+ renderGradient(p, TQRect(r.left(),r.top(), checkcol+4,r.bottom()-r.top()+1), getColor(cg, MenuStripeColor), cg.background().light( 105 ), false);
} else {
- renderGradient(p, TQRect(r.left(),r.top(), checkcol+4,r.bottom()-r.top()+1),cg.background().light( 105 ), getColo$
+ renderGradient(p, TQRect(r.left(),r.top(), checkcol+4,r.bottom()-r.top()+1),cg.background().light( 105 ), getColor(cg, MenuStripeColor), false);
}
}
}
@@ -1,4 +1,4 @@
-/* Lipstik widget style for KDE 3
+/* Lipstik widget style for TDE
Copyright (C) 2004-2007 Patrice Tremblay <poplixos@gmail.com>
http://www.poplix.info/lipstik